@@ -1,7 +1,8 @@
 # pylint: disable=wildcard-import, unused-import
+import miniscule.aws
 from miniscule.base import *
+from miniscule.facade import init
 from miniscule.logs import *
 from miniscule.main import main
-import miniscule.aws
 
-__all__ = ["read_config", "load_config", "init_logging", "main"]
+__all__ = ["read_config", "load_config", "init_logging", "main", "init"]
