@@ -11,6 +11,11 @@ log = logging.getLogger(__name__)
 try:
     import boto3
     import botocore
+
+    IGNORED_EXCEPTIONS = (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.NoCredentialsError,
+    )
 except ImportError:
     pass
 else:
@@ -34,7 +39,7 @@ else:
         try:
             response = client.get_secret_value(SecretId=friendly_name)
             secret_string = response.get("SecretString")
-        except botocore.exceptions.ClientError as exc:
+        except IGNORED_EXCEPTIONS as exc:
             log.warning(
                 "Unable to obtain secrets manager value for %s: %s", friendly_name, exc
             )
