@@ -1,11 +1,15 @@
 import sys
 from argparse import ArgumentParser
+import logging
 
 import yaml
 from miniscule.base import read_config, load_config
 from miniscule.logs import init_logging
 
 
+log = logging.getLogger(__name__)
+
+
 def _create_parser():
     parser = ArgumentParser()
     parser.add_argument("path", metavar="PATH", nargs="?")
